/*
** Hello Name Client
*/

#include <cbcp.h>
#define CBCP_NET_TCP_IMPLEMENTATION
#include <cbcp_net_tcp.h>

#include <stdio.h>
#include <string.h>



/*
** CBCP program
*/
int main(int argc, char const *argv[]) {
	if (argc < 3) {
		fprintf(stderr, "Usage:\n\t%s <cbcp_database_filepath>\n", argv[0]);
		return 1;
	}

	/*
	** Initialize CBCP by loading the database file for this host
	*/

	const char *cbcp_database_filepath = argv[1];
	CBCP_State *cbcp;

	cbcp_net_tcp_init(0);
	cbcp = cbcp_init(cbcp_database_filepath);

	if (cbcp == NULL) {
		fprintf(stderr, "Could not initialize CBCP.\n");
		return 1;
	}

	/*
	** Init commands
	*/

	CBCP_Command *command_hello_world;
	command_hello_world = cbcp_client_init_command(
		cbcp,
		"Server",
		"Hello Name",
		"Hello");

	if (!command_hello_world) {
		fprintf(stderr, "Could not initialize required command.\n");
		return 1;
	}

	/*
	** Client code here
	*/

	const char *name = argv[2];
	unsigned int name_length = strlen(name);

	printf(
		"Sending cbcp command to the server with payload %.*s.\n",
		name_length,
		name);

	CBCP_Response response;

	response = cbcp_client_send_command(
		command_hello_world,
		(void*)name,
		name_length,
		NULL,
		0);

	if(response.success)
		printf("Server has received the command.\n");
	else
		printf("Sending command to server was not successful!\n");

	return 0;
}

